"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useFullScreenHandle = useFullScreenHandle;
exports.FullScreen = void 0;

var React = _interopRequireWildcard(require("react"));

var _fscreen = _interopRequireDefault(require("fscreen"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function useFullScreenHandle() {
  const [active, setActive] = React.useState(false);
  const node = React.useRef(null);
  React.useEffect(() => {
    const handleChange = () => {
      setActive(_fscreen.default.fullscreenElement === node.current);
    };

    _fscreen.default.addEventListener("fullscreenchange", handleChange);

    return () => _fscreen.default.removeEventListener("fullscreenchange", handleChange);
  }, []);
  const enter = React.useCallback(() => {
    if (_fscreen.default.fullscreenElement) {
      return _fscreen.default.exitFullscreen().then(() => {
        return _fscreen.default.requestFullscreen(node.current);
      });
    } else if (node.current) {
      return _fscreen.default.requestFullscreen(node.current);
    }
  }, []);
  const exit = React.useCallback(() => {
    if (_fscreen.default.fullscreenElement === node.current) {
      return _fscreen.default.exitFullscreen();
    }

    return Promise.resolve();
  }, []);
  return {
    active,
    enter,
    exit,
    node
  };
}

const FullScreen = ({
  handle,
  onChange,
  children,
  className
}) => {
  const classNames = [];

  if (className) {
    classNames.push(className);
  }

  classNames.push("fullscreen");

  if (handle.active) {
    classNames.push("fullscreen-enabled");
  }

  React.useEffect(() => {
    if (onChange) {
      onChange(handle.active, handle);
    }
  }, [handle.active]);
  return /*#__PURE__*/React.createElement("div", {
    className: classNames.join(" "),
    ref: handle.node,
    style: handle.active ? {
      height: "100%",
      width: "100%"
    } : undefined
  }, children);
};

exports.FullScreen = FullScreen;
//# sourceMappingURL=Fullscreen.js.map