import * as React from "react";
import fscreen from "fscreen";
export function useFullScreenHandle() {
  const [active, setActive] = React.useState(false);
  const node = React.useRef(null);
  React.useEffect(() => {
    const handleChange = () => {
      setActive(fscreen.fullscreenElement === node.current);
    };

    fscreen.addEventListener("fullscreenchange", handleChange);
    return () => fscreen.removeEventListener("fullscreenchange", handleChange);
  }, []);
  const enter = React.useCallback(() => {
    if (fscreen.fullscreenElement) {
      return fscreen.exitFullscreen().then(() => {
        return fscreen.requestFullscreen(node.current);
      });
    } else if (node.current) {
      return fscreen.requestFullscreen(node.current);
    }
  }, []);
  const exit = React.useCallback(() => {
    if (fscreen.fullscreenElement === node.current) {
      return fscreen.exitFullscreen();
    }

    return Promise.resolve();
  }, []);
  return {
    active,
    enter,
    exit,
    node
  };
}
export const FullScreen = ({
  handle,
  onChange,
  children,
  className
}) => {
  const classNames = [];

  if (className) {
    classNames.push(className);
  }

  classNames.push("fullscreen");

  if (handle.active) {
    classNames.push("fullscreen-enabled");
  }

  React.useEffect(() => {
    if (onChange) {
      onChange(handle.active, handle);
    }
  }, [handle.active]);
  return /*#__PURE__*/React.createElement("div", {
    className: classNames.join(" "),
    ref: handle.node,
    style: handle.active ? {
      height: "100%",
      width: "100%"
    } : undefined
  }, children);
};
//# sourceMappingURL=Fullscreen.js.map